@@ -11,7 +11,7 @@ import os
 
 __author__ = "Shyue Ping Ong, Dan Gunter"
 __date__ = "Jul 22 2017"
-__version__ = "2022.3.17"
+__version__ = "2022.5.2"
 
 
 from .query_engine import QueryEngine
@@ -21,8 +21,9 @@ SETTINGS_FILE = os.path.join(os.path.expanduser("~"), ".pmgrc.yaml")
 
 def _load_mgdb_settings():
     try:
-        import ruamel.yaml as yaml
+        from ruamel.yaml import YAML
 
+        yaml = YAML()
         with open(SETTINGS_FILE) as f:
             d = yaml.load(f)
     except OSError:
