@@ -1,40 +1,38 @@
-#!/usr/bin/env python
-
 """
 This module defines a Drone to assimilate vasp data and insert it into a
 Mongo database.
 """
 
 
+import datetime
+import glob
+import json
+import logging
 import os
 import re
-import glob
-import logging
-import datetime
-import string
-import json
 import socket
-import numpy as np
+import string
 import zlib
-from fnmatch import fnmatch
 from collections import OrderedDict
+from fnmatch import fnmatch
 
-from pymongo import MongoClient
 import gridfs
-
-from pymatgen.apps.borg.hive import AbstractDrone
-from pymatgen.analysis.local_env import VoronoiNN
-from pymatgen.core.structure import Structure
-from pymatgen.core.composition import Composition
-from pymatgen.io.vasp import Vasprun, Incar, Kpoints, Potcar, Poscar, Outcar, Oszicar
-from pymatgen.io.cif import CifWriter
-from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
-from pymatgen.analysis.bond_valence import BVAnalyzer
+import numpy as np
+from pymongo import MongoClient
 from monty.io import zopen
-from pymatgen.ext.matproj import MPRester
-from pymatgen.entries.computed_entries import ComputedEntry
-from pymatgen.analysis.structure_analyzer import oxide_type
 from monty.json import MontyEncoder
+from pymatgen.analysis.bond_valence import BVAnalyzer
+from pymatgen.analysis.local_env import VoronoiNN
+from pymatgen.analysis.structure_analyzer import oxide_type
+from pymatgen.apps.borg.hive import AbstractDrone
+from pymatgen.core.composition import Composition
+from pymatgen.core.structure import Structure
+from pymatgen.entries.computed_entries import ComputedEntry
+from pymatgen.ext.matproj import MPRester
+from pymatgen.io.cif import CifWriter
+from pymatgen.io.vasp import Incar, Kpoints, Oszicar, Outcar, Poscar, Potcar, Vasprun
+from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
+
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -192,13 +190,16 @@ class VaspToDbTaskDrone(AbstractDrone):
                 self.calculate_stability(d)
             tid = self._insert_doc(d)
             return tid
-        except Exception as ex:
+        except Exception:
             import traceback
 
             logger.error(traceback.format_exc())
             return False
 
     def calculate_stability(self, d):
+        """
+        Calculate the stability (e_above_hull and decomposes_to) for a entry dict.
+        """
         m = MPRester(self.mapi_key)
         functional = d["pseudo_potential"]["functional"]
         syms = [f"{functional} {l}" for l in d["pseudo_potential"]["labels"]]
@@ -283,19 +284,19 @@ class VaspToDbTaskDrone(AbstractDrone):
                     if ("task_id" not in d) or (not d["task_id"]):
                         result = db.counter.find_one_and_update(filter={"_id": "taskid"}, update={"$inc": {"c": 1}})
                         d["task_id"] = result["c"]
-                    logger.info("Inserting {} with taskid = {}".format(d["dir_name"], d["task_id"]))
+                    logger.info(f"Inserting {d['dir_name']} with taskid = {d['task_id']}")
                 elif self.update_duplicates:
                     d["task_id"] = result["task_id"]
-                    logger.info("Updating {} with taskid = {}".format(d["dir_name"], d["task_id"]))
+                    logger.info(f"Updating {d['dir_name']} with taskid = {d['task_id']}")
 
                 coll.update_one({"dir_name": d["dir_name"]}, {"$set": d}, upsert=True)
                 return d["task_id"]
-            else:
-                logger.info("Skipping duplicate {}".format(d["dir_name"]))
+            logger.info(f"Skipping duplicate {d['dir_name']}")
         else:
             d["task_id"] = 0
-            logger.info("Simulated insert into database for {} with task_id {}".format(d["dir_name"], d["task_id"]))
+            logger.info(f"Simulated insert into database for {d['dir_name']} with task_id {d['task_id']}")
             return d
+        return None
 
     def post_process(self, dir_name, d):
         """
@@ -327,7 +328,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                     m = re.match(r"(\d+)-ICSD", transformations["history"][0]["source"])
                     if m:
                         d["icsd_id"] = int(m.group(1))
-                except Exception as ex:
+                except Exception:
                     logger.warning("Cannot parse ICSD from transformations " "file.")
                     pass
         else:
@@ -368,7 +369,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                 taskname = "relax2" if re.search("relax2", filename) else "relax1"
                 d["calculations"][i]["output"]["outcar"] = outcar.as_dict()
                 run_stats[taskname] = outcar.run_stats
-        except:
+        except Exception:
             logger.error(f"Bad OUTCAR for {fullpath}.")
 
         try:
@@ -381,7 +382,7 @@ class VaspToDbTaskDrone(AbstractDrone):
             ]:
                 overall_run_stats[key] = sum(v[key] for v in run_stats.values())
             run_stats["overall"] = overall_run_stats
-        except:
+        except Exception:
             logger.error(f"Bad run stats for {fullpath}.")
 
         d["run_stats"] = run_stats
@@ -395,7 +396,7 @@ class VaspToDbTaskDrone(AbstractDrone):
 
         logger.info("Post-processed " + fullpath)
 
-    def process_killed_run(self, dir_name):
+    def process_killed_run(self, dir_name):  # pylint: disable=R0201
         """
         Process a killed vasp run.
         """
@@ -431,7 +432,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                 try:
                     kpoints = Kpoints.from_file(filename)
                     d["kpoints"] = kpoints.as_dict()
-                except:
+                except Exception:
                     logger.error(f"Unable to parse KPOINTS for killed run {dir_name}.")
             elif fnmatch(f, "POSCAR*"):
                 try:
@@ -451,7 +452,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                         }
                     )
                     d["poscar"] = s.as_dict()
-                except:
+                except Exception:
                     logger.error(f"Unable to parse POSCAR for killed run {dir_name}.")
             elif fnmatch(f, "POTCAR*"):
                 try:
@@ -461,19 +462,19 @@ class VaspToDbTaskDrone(AbstractDrone):
                         "pot_type": "paw",
                         "labels": potcar.symbols,
                     }
-                except:
+                except Exception:
                     logger.error(f"Unable to parse POTCAR for killed run in {dir_name}.")
             elif fnmatch(f, "OSZICAR"):
                 try:
                     d["oszicar"]["root"] = Oszicar(os.path.join(dir_name, f)).as_dict()
-                except:
+                except Exception:
                     logger.error(f"Unable to parse OSZICAR for killed run in {dir_name}.")
             elif re.match(r"relax\d", f):
                 if os.path.exists(os.path.join(dir_name, f, "OSZICAR")):
                     try:
                         d["oszicar"][f] = Oszicar(os.path.join(dir_name, f, "OSZICAR")).as_dict()
-                    except:
-                        logger.error("Unable to parse OSZICAR for killed " "run in {}.".format(dir_name))
+                    except Exception:
+                        logger.error(f"Unable to parse OSZICAR for killed run in {dir_name}.")
         return d
 
     def process_vasprun(self, dir_name, taskname, filename):
@@ -481,10 +482,9 @@ class VaspToDbTaskDrone(AbstractDrone):
         Process a vasprun.xml file.
         """
         vasprun_file = os.path.join(dir_name, filename)
-        if self.parse_projected_eigen and (self.parse_projected_eigen != "final" or taskname == self.runs[-1]):
-            parse_projected_eigen = True
-        else:
-            parse_projected_eigen = False
+        parse_projected_eigen = self.parse_projected_eigen and (
+            self.parse_projected_eigen != "final" or taskname == self.runs[-1]
+        )
         r = Vasprun(vasprun_file, parse_projected_eigen=parse_projected_eigen)
         d = r.as_dict()
         d["dir_name"] = os.path.abspath(dir_name)
@@ -496,7 +496,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                 d["dos"] = r.complete_dos.as_dict()
             except Exception:
                 logger.warning(f"No valid dos data exist in {dir_name}.\n Skipping dos")
-        if taskname == "relax1" or taskname == "relax2":
+        if taskname in ("relax1", "relax2"):
             d["task"] = {"type": "aflow", "name": taskname}
         else:
             d["task"] = {"type": taskname, "name": taskname}
@@ -513,7 +513,7 @@ class VaspToDbTaskDrone(AbstractDrone):
             # Defensively copy the additional fields first.  This is a MUST.
             # Otherwise, parallel updates will see the same object and inserts
             # will be overridden!!
-            d = {k: v for k, v in self.additional_fields.items()}
+            d = dict(self.additional_fields.items())
             d["dir_name"] = fullpath
             d["schema_version"] = VaspToDbTaskDrone.__version__
             d["calculations"] = [
@@ -584,7 +584,7 @@ class VaspToDbTaskDrone(AbstractDrone):
             d["oxide_type"] = d2["oxide_type"]
             d["last_updated"] = datetime.datetime.today()
             return d
-        except Exception as ex:
+        except Exception:
             import traceback
 
             print(traceback.format_exc())
@@ -607,13 +607,16 @@ class VaspToDbTaskDrone(AbstractDrone):
         if set(self.runs).intersection(subdirs):
             return [parent]
         if (
-            not any([parent.endswith(os.sep + r) for r in self.runs])
+            not any(parent.endswith(os.sep + r) for r in self.runs)
             and len(glob.glob(os.path.join(parent, "vasprun.xml*"))) > 0
         ):
             return [parent]
         return []
 
-    def convert(self, d):
+    def convert(self, d):  # pylint: disable=R0201
+        """
+        Just return the dict.
+        """
         return d
 
     def __str__(self):
@@ -621,9 +624,15 @@ class VaspToDbTaskDrone(AbstractDrone):
 
     @classmethod
     def from_dict(cls, d):
+        """
+        From dict
+        """
         return cls(**d["init_args"])
 
     def as_dict(self):
+        """
+        Dict representation.
+        """
         init_args = {
             "host": self.host,
             "port": self.port,
@@ -645,7 +654,9 @@ class VaspToDbTaskDrone(AbstractDrone):
 
 
 def get_basic_analysis_and_error_checks(d, max_force_threshold=0.5, volume_change_threshold=0.2):
-
+    """
+    Generate basic analysis and error checks data for a run.
+    """
     initial_vol = d["input"]["crystal"]["lattice"]["volume"]
     final_vol = d["output"]["crystal"]["lattice"]["volume"]
     delta_vol = final_vol - initial_vol
@@ -760,6 +771,6 @@ def get_uri(dir_name):
     fullpath = os.path.abspath(dir_name)
     try:
         hostname = socket.gethostbyaddr(socket.gethostname())[0]
-    except:
+    except Exception:
         hostname = socket.gethostname()
     return f"{hostname}:{fullpath}"
